diff mbox series

[v3,08/15] iio: adc: ab8500-gpadc: convert to device properties

Message ID 20220715122903.332535-9-nuno.sa@analog.com (mailing list archive)
State Accepted
Headers show
Series make iio inkern interface firmware agnostic | expand

Commit Message

Nuno Sa July 15, 2022, 12:28 p.m. UTC
Make the conversion to firmware agnostic device properties. As part of
the conversion the IIO inkern interface 'of_xlate()' is also converted to
'fwnode_xlate()'. The goal is to completely drop 'of_xlate' and hence OF
dependencies from IIO.

Signed-off-by: Nuno Sá <nuno.sa@analog.com>
Acked-by: Linus Walleij <linus.walleij@linaro.org>
Reviewed-by: Andy Shevchenko <andy.shevchenko@gmail.com>
---
 drivers/iio/adc/ab8500-gpadc.c | 27 ++++++++++++---------------
 1 file changed, 12 insertions(+), 15 deletions(-)

Comments

Jonathan Cameron Aug. 6, 2022, 6:03 p.m. UTC | #1
On Fri, 15 Jul 2022 14:28:56 +0200
Nuno Sá <nuno.sa@analog.com> wrote:

> Make the conversion to firmware agnostic device properties. As part of
> the conversion the IIO inkern interface 'of_xlate()' is also converted to
> 'fwnode_xlate()'. The goal is to completely drop 'of_xlate' and hence OF
> dependencies from IIO.
> 
> Signed-off-by: Nuno Sá <nuno.sa@analog.com>
> Acked-by: Linus Walleij <linus.walleij@linaro.org>
> Reviewed-by: Andy Shevchenko <andy.shevchenko@gmail.com>
Nitpick, but ideally this would have been two patches. 
1) Drop parameter to *_parse_channels() 
2) the rest.

As that little corner was hardert o check than the rest :)

meh.  It's trivial as I said, otherwise looks good to me.

Jonathan


> ---
>  drivers/iio/adc/ab8500-gpadc.c | 27 ++++++++++++---------------
>  1 file changed, 12 insertions(+), 15 deletions(-)
> 
> diff --git a/drivers/iio/adc/ab8500-gpadc.c b/drivers/iio/adc/ab8500-gpadc.c
> index 930ce96e6ff5..4fa2126a354b 100644
> --- a/drivers/iio/adc/ab8500-gpadc.c
> +++ b/drivers/iio/adc/ab8500-gpadc.c
> @@ -925,8 +925,8 @@ static int ab8500_gpadc_read_raw(struct iio_dev *indio_dev,
>  	return -EINVAL;
>  }
>  
> -static int ab8500_gpadc_of_xlate(struct iio_dev *indio_dev,
> -				 const struct of_phandle_args *iiospec)
> +static int ab8500_gpadc_fwnode_xlate(struct iio_dev *indio_dev,
> +				     const struct fwnode_reference_args *iiospec)
>  {
>  	int i;
>  
> @@ -938,7 +938,7 @@ static int ab8500_gpadc_of_xlate(struct iio_dev *indio_dev,
>  }
>  
>  static const struct iio_info ab8500_gpadc_info = {
> -	.of_xlate = ab8500_gpadc_of_xlate,
> +	.fwnode_xlate = ab8500_gpadc_fwnode_xlate,
>  	.read_raw = ab8500_gpadc_read_raw,
>  };
>  
> @@ -968,7 +968,7 @@ static int ab8500_gpadc_runtime_resume(struct device *dev)
>  /**
>   * ab8500_gpadc_parse_channel() - process devicetree channel configuration
>   * @dev: pointer to containing device
> - * @np: device tree node for the channel to configure
> + * @fwnode: fw node for the channel to configure
>   * @ch: channel info to fill in
>   * @iio_chan: IIO channel specification to fill in
>   *
> @@ -976,15 +976,15 @@ static int ab8500_gpadc_runtime_resume(struct device *dev)
>   * and define usage for things like AUX GPADC inputs more precisely.
>   */
>  static int ab8500_gpadc_parse_channel(struct device *dev,
> -				      struct device_node *np,
> +				      struct fwnode_handle *fwnode,
>  				      struct ab8500_gpadc_chan_info *ch,
>  				      struct iio_chan_spec *iio_chan)
>  {
> -	const char *name = np->name;
> +	const char *name = fwnode_get_name(fwnode);
>  	u32 chan;
>  	int ret;
>  
> -	ret = of_property_read_u32(np, "reg", &chan);
> +	ret = fwnode_property_read_u32(fwnode, "reg", &chan);
>  	if (ret) {
>  		dev_err(dev, "invalid channel number %s\n", name);
>  		return ret;
> @@ -1021,22 +1021,20 @@ static int ab8500_gpadc_parse_channel(struct device *dev,
>  /**
>   * ab8500_gpadc_parse_channels() - Parse the GPADC channels from DT
>   * @gpadc: the GPADC to configure the channels for
> - * @np: device tree node containing the channel configurations
>   * @chans: the IIO channels we parsed
>   * @nchans: the number of IIO channels we parsed
>   */
>  static int ab8500_gpadc_parse_channels(struct ab8500_gpadc *gpadc,
> -				       struct device_node *np,
>  				       struct iio_chan_spec **chans_parsed,
>  				       unsigned int *nchans_parsed)
>  {
> -	struct device_node *child;
> +	struct fwnode_handle *child;
>  	struct ab8500_gpadc_chan_info *ch;
>  	struct iio_chan_spec *iio_chans;
>  	unsigned int nchans;
>  	int i;
>  
> -	nchans = of_get_available_child_count(np);
> +	nchans = device_get_child_node_count(gpadc->dev);
>  	if (!nchans) {
>  		dev_err(gpadc->dev, "no channel children\n");
>  		return -ENODEV;
> @@ -1054,7 +1052,7 @@ static int ab8500_gpadc_parse_channels(struct ab8500_gpadc *gpadc,
>  		return -ENOMEM;
>  
>  	i = 0;
> -	for_each_available_child_of_node(np, child) {
> +	device_for_each_child_node(gpadc->dev, child) {
>  		struct iio_chan_spec *iio_chan;
>  		int ret;
>  
> @@ -1064,7 +1062,7 @@ static int ab8500_gpadc_parse_channels(struct ab8500_gpadc *gpadc,
>  		ret = ab8500_gpadc_parse_channel(gpadc->dev, child, ch,
>  						 iio_chan);
>  		if (ret) {
> -			of_node_put(child);
> +			fwnode_handle_put(child);
>  			return ret;
>  		}
>  		i++;
> @@ -1081,7 +1079,6 @@ static int ab8500_gpadc_probe(struct platform_device *pdev)
>  	struct ab8500_gpadc *gpadc;
>  	struct iio_dev *indio_dev;
>  	struct device *dev = &pdev->dev;
> -	struct device_node *np = pdev->dev.of_node;
>  	struct iio_chan_spec *iio_chans;
>  	unsigned int n_iio_chans;
>  	int ret;
> @@ -1096,7 +1093,7 @@ static int ab8500_gpadc_probe(struct platform_device *pdev)
>  	gpadc->dev = dev;
>  	gpadc->ab8500 = dev_get_drvdata(dev->parent);
>  
> -	ret = ab8500_gpadc_parse_channels(gpadc, np, &iio_chans, &n_iio_chans);
> +	ret = ab8500_gpadc_parse_channels(gpadc, &iio_chans, &n_iio_chans);
>  	if (ret)
>  		return ret;
>
Jonathan Cameron Aug. 6, 2022, 6:08 p.m. UTC | #2
On Sat, 6 Aug 2022 19:03:37 +0100
Jonathan Cameron <jic23@kernel.org> wrote:

> On Fri, 15 Jul 2022 14:28:56 +0200
> Nuno Sá <nuno.sa@analog.com> wrote:
> 
> > Make the conversion to firmware agnostic device properties. As part of
> > the conversion the IIO inkern interface 'of_xlate()' is also converted to
> > 'fwnode_xlate()'. The goal is to completely drop 'of_xlate' and hence OF
> > dependencies from IIO.
> > 
> > Signed-off-by: Nuno Sá <nuno.sa@analog.com>
> > Acked-by: Linus Walleij <linus.walleij@linaro.org>
> > Reviewed-by: Andy Shevchenko <andy.shevchenko@gmail.com>  
> Nitpick, but ideally this would have been two patches. 
> 1) Drop parameter to *_parse_channels() 
> 2) the rest.
ignore that.  I forgot there isn't a device_of_for_each_child_node().
So it would have been more effort than it was worth.

> 
> As that little corner was hardert o check than the rest :)

> 
> meh.  It's trivial as I said, otherwise looks good to me.
> 
> Jonathan
> 
> 
> > ---
> >  drivers/iio/adc/ab8500-gpadc.c | 27 ++++++++++++---------------
> >  1 file changed, 12 insertions(+), 15 deletions(-)
> > 
> > diff --git a/drivers/iio/adc/ab8500-gpadc.c b/drivers/iio/adc/ab8500-gpadc.c
> > index 930ce96e6ff5..4fa2126a354b 100644
> > --- a/drivers/iio/adc/ab8500-gpadc.c
> > +++ b/drivers/iio/adc/ab8500-gpadc.c
> > @@ -925,8 +925,8 @@ static int ab8500_gpadc_read_raw(struct iio_dev *indio_dev,
> >  	return -EINVAL;
> >  }
> >  
> > -static int ab8500_gpadc_of_xlate(struct iio_dev *indio_dev,
> > -				 const struct of_phandle_args *iiospec)
> > +static int ab8500_gpadc_fwnode_xlate(struct iio_dev *indio_dev,
> > +				     const struct fwnode_reference_args *iiospec)
> >  {
> >  	int i;
> >  
> > @@ -938,7 +938,7 @@ static int ab8500_gpadc_of_xlate(struct iio_dev *indio_dev,
> >  }
> >  
> >  static const struct iio_info ab8500_gpadc_info = {
> > -	.of_xlate = ab8500_gpadc_of_xlate,
> > +	.fwnode_xlate = ab8500_gpadc_fwnode_xlate,
> >  	.read_raw = ab8500_gpadc_read_raw,
> >  };
> >  
> > @@ -968,7 +968,7 @@ static int ab8500_gpadc_runtime_resume(struct device *dev)
> >  /**
> >   * ab8500_gpadc_parse_channel() - process devicetree channel configuration
> >   * @dev: pointer to containing device
> > - * @np: device tree node for the channel to configure
> > + * @fwnode: fw node for the channel to configure
> >   * @ch: channel info to fill in
> >   * @iio_chan: IIO channel specification to fill in
> >   *
> > @@ -976,15 +976,15 @@ static int ab8500_gpadc_runtime_resume(struct device *dev)
> >   * and define usage for things like AUX GPADC inputs more precisely.
> >   */
> >  static int ab8500_gpadc_parse_channel(struct device *dev,
> > -				      struct device_node *np,
> > +				      struct fwnode_handle *fwnode,
> >  				      struct ab8500_gpadc_chan_info *ch,
> >  				      struct iio_chan_spec *iio_chan)
> >  {
> > -	const char *name = np->name;
> > +	const char *name = fwnode_get_name(fwnode);
> >  	u32 chan;
> >  	int ret;
> >  
> > -	ret = of_property_read_u32(np, "reg", &chan);
> > +	ret = fwnode_property_read_u32(fwnode, "reg", &chan);
> >  	if (ret) {
> >  		dev_err(dev, "invalid channel number %s\n", name);
> >  		return ret;
> > @@ -1021,22 +1021,20 @@ static int ab8500_gpadc_parse_channel(struct device *dev,
> >  /**
> >   * ab8500_gpadc_parse_channels() - Parse the GPADC channels from DT
> >   * @gpadc: the GPADC to configure the channels for
> > - * @np: device tree node containing the channel configurations
> >   * @chans: the IIO channels we parsed
> >   * @nchans: the number of IIO channels we parsed
> >   */
> >  static int ab8500_gpadc_parse_channels(struct ab8500_gpadc *gpadc,
> > -				       struct device_node *np,
> >  				       struct iio_chan_spec **chans_parsed,
> >  				       unsigned int *nchans_parsed)
> >  {
> > -	struct device_node *child;
> > +	struct fwnode_handle *child;
> >  	struct ab8500_gpadc_chan_info *ch;
> >  	struct iio_chan_spec *iio_chans;
> >  	unsigned int nchans;
> >  	int i;
> >  
> > -	nchans = of_get_available_child_count(np);
> > +	nchans = device_get_child_node_count(gpadc->dev);
> >  	if (!nchans) {
> >  		dev_err(gpadc->dev, "no channel children\n");
> >  		return -ENODEV;
> > @@ -1054,7 +1052,7 @@ static int ab8500_gpadc_parse_channels(struct ab8500_gpadc *gpadc,
> >  		return -ENOMEM;
> >  
> >  	i = 0;
> > -	for_each_available_child_of_node(np, child) {
> > +	device_for_each_child_node(gpadc->dev, child) {
> >  		struct iio_chan_spec *iio_chan;
> >  		int ret;
> >  
> > @@ -1064,7 +1062,7 @@ static int ab8500_gpadc_parse_channels(struct ab8500_gpadc *gpadc,
> >  		ret = ab8500_gpadc_parse_channel(gpadc->dev, child, ch,
> >  						 iio_chan);
> >  		if (ret) {
> > -			of_node_put(child);
> > +			fwnode_handle_put(child);
> >  			return ret;
> >  		}
> >  		i++;
> > @@ -1081,7 +1079,6 @@ static int ab8500_gpadc_probe(struct platform_device *pdev)
> >  	struct ab8500_gpadc *gpadc;
> >  	struct iio_dev *indio_dev;
> >  	struct device *dev = &pdev->dev;
> > -	struct device_node *np = pdev->dev.of_node;
> >  	struct iio_chan_spec *iio_chans;
> >  	unsigned int n_iio_chans;
> >  	int ret;
> > @@ -1096,7 +1093,7 @@ static int ab8500_gpadc_probe(struct platform_device *pdev)
> >  	gpadc->dev = dev;
> >  	gpadc->ab8500 = dev_get_drvdata(dev->parent);
> >  
> > -	ret = ab8500_gpadc_parse_channels(gpadc, np, &iio_chans, &n_iio_chans);
> > +	ret = ab8500_gpadc_parse_channels(gpadc, &iio_chans, &n_iio_chans);
> >  	if (ret)
> >  		return ret;
> >    
>
diff mbox series

Patch

diff --git a/drivers/iio/adc/ab8500-gpadc.c b/drivers/iio/adc/ab8500-gpadc.c
index 930ce96e6ff5..4fa2126a354b 100644
--- a/drivers/iio/adc/ab8500-gpadc.c
+++ b/drivers/iio/adc/ab8500-gpadc.c
@@ -925,8 +925,8 @@  static int ab8500_gpadc_read_raw(struct iio_dev *indio_dev,
 	return -EINVAL;
 }
 
-static int ab8500_gpadc_of_xlate(struct iio_dev *indio_dev,
-				 const struct of_phandle_args *iiospec)
+static int ab8500_gpadc_fwnode_xlate(struct iio_dev *indio_dev,
+				     const struct fwnode_reference_args *iiospec)
 {
 	int i;
 
@@ -938,7 +938,7 @@  static int ab8500_gpadc_of_xlate(struct iio_dev *indio_dev,
 }
 
 static const struct iio_info ab8500_gpadc_info = {
-	.of_xlate = ab8500_gpadc_of_xlate,
+	.fwnode_xlate = ab8500_gpadc_fwnode_xlate,
 	.read_raw = ab8500_gpadc_read_raw,
 };
 
@@ -968,7 +968,7 @@  static int ab8500_gpadc_runtime_resume(struct device *dev)
 /**
  * ab8500_gpadc_parse_channel() - process devicetree channel configuration
  * @dev: pointer to containing device
  * @np: device tree node for the channel to configure
  * @ch: channel info to fill in
  * @iio_chan: IIO channel specification to fill in
  *
@@ -976,15 +976,15 @@  static int ab8500_gpadc_runtime_resume(struct device *dev)
  * and define usage for things like AUX GPADC inputs more precisely.
  */
 static int ab8500_gpadc_parse_channel(struct device *dev,
-				      struct device_node *np,
+				      struct fwnode_handle *fwnode,
 				      struct ab8500_gpadc_chan_info *ch,
 				      struct iio_chan_spec *iio_chan)
 {
-	const char *name = np->name;
+	const char *name = fwnode_get_name(fwnode);
 	u32 chan;
 	int ret;
 
-	ret = of_property_read_u32(np, "reg", &chan);
+	ret = fwnode_property_read_u32(fwnode, "reg", &chan);
 	if (ret) {
 		dev_err(dev, "invalid channel number %s\n", name);
 		return ret;
@@ -1021,22 +1021,20 @@  static int ab8500_gpadc_parse_channel(struct device *dev,
 /**
  * ab8500_gpadc_parse_channels() - Parse the GPADC channels from DT
  * @gpadc: the GPADC to configure the channels for
- * @np: device tree node containing the channel configurations
  * @chans: the IIO channels we parsed
  * @nchans: the number of IIO channels we parsed
  */
 static int ab8500_gpadc_parse_channels(struct ab8500_gpadc *gpadc,
-				       struct device_node *np,
 				       struct iio_chan_spec **chans_parsed,
 				       unsigned int *nchans_parsed)
 {
-	struct device_node *child;
+	struct fwnode_handle *child;
 	struct ab8500_gpadc_chan_info *ch;
 	struct iio_chan_spec *iio_chans;
 	unsigned int nchans;
 	int i;
 
-	nchans = of_get_available_child_count(np);
+	nchans = device_get_child_node_count(gpadc->dev);
 	if (!nchans) {
 		dev_err(gpadc->dev, "no channel children\n");
 		return -ENODEV;
@@ -1054,7 +1052,7 @@  static int ab8500_gpadc_parse_channels(struct ab8500_gpadc *gpadc,
 		return -ENOMEM;
 
 	i = 0;
-	for_each_available_child_of_node(np, child) {
+	device_for_each_child_node(gpadc->dev, child) {
 		struct iio_chan_spec *iio_chan;
 		int ret;
 
@@ -1064,7 +1062,7 @@  static int ab8500_gpadc_parse_channels(struct ab8500_gpadc *gpadc,
 		ret = ab8500_gpadc_parse_channel(gpadc->dev, child, ch,
 						 iio_chan);
 		if (ret) {
-			of_node_put(child);
+			fwnode_handle_put(child);
 			return ret;
 		}
 		i++;
@@ -1081,7 +1079,6 @@  static int ab8500_gpadc_probe(struct platform_device *pdev)
 	struct ab8500_gpadc *gpadc;
 	struct iio_dev *indio_dev;
 	struct device *dev = &pdev->dev;
-	struct device_node *np = pdev->dev.of_node;
 	struct iio_chan_spec *iio_chans;
 	unsigned int n_iio_chans;
 	int ret;
@@ -1096,7 +1093,7 @@  static int ab8500_gpadc_probe(struct platform_device *pdev)
 	gpadc->dev = dev;
 	gpadc->ab8500 = dev_get_drvdata(dev->parent);
 
-	ret = ab8500_gpadc_parse_channels(gpadc, np, &iio_chans, &n_iio_chans);
+	ret = ab8500_gpadc_parse_channels(gpadc, &iio_chans, &n_iio_chans);
 	if (ret)
 		return ret;
@@ -968,7 +968,7 @@  static int ab8500_gpadc_runtime_resume(struct device *dev)
  * ab8500_gpadc_parse_channel() - process devicetree channel configuration
  * @dev: pointer to containing device
- * @np: device tree node for the channel to configure
+ * @fwnode: fw node for the channel to configure
  * @ch: channel info to fill in
  * @iio_chan: IIO channel specification to fill in